"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var chai = require("chai");
var install_1 = require("../standalone/install");
var pact_util_1 = require("./pact-util");
var pact_standalone_1 = require("./pact-standalone");
var expect = chai.expect;
var basePath = pact_util_1.default.binaryBasePath;
describe("Pact Standalone", function () {
    this.timeout(600000);
    var pact;
    after(function () { return install_1.default(); });
    it("should return an object with binaryBasePath, file and fullPath properties that is platform specific", function () {
        pact = pact_standalone_1.standalone();
        expect(pact).to.be.an("object");
        expect(pact.cwd).to.be.ok;
        expect(pact.brokerRelativePath).to.contain("pact-broker");
        expect(pact.brokerAbsolutePath).to.contain("pact-broker");
        expect(pact.mockServiceRelativePath).to.contain("pact-mock-service");
        expect(pact.mockServiceAbsolutePath).to.contain("pact-mock-service");
        expect(pact.stubRelativePath).to.contain("pact-stub-service");
        expect(pact.stubAbsolutePath).to.contain("pact-stub-service");
        expect(pact.verifierRelativePath).to.contain("pact-provider-verifier");
        expect(pact.verifierAbsolutePath).to.contain("pact-provider-verifier");
    });
    it("should return the base directory of the project with 'binaryBasePath' (where the package.json file is)", function () {
        expect(fs.existsSync(pact.cwd)).to.be.true;
    });
    describe("Check if OS specific files are there", function () {
        describe("OSX", function () {
            before(function () { return install_1.default("darwin"); });
            beforeEach(function () { return pact = pact_standalone_1.standalone("darwin"); });
            it("broker relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.brokerRelativePath))).to.be.true;
            });
            it("broker full path", function () {
                expect(fs.existsSync(pact.brokerAbsolutePath)).to.be.true;
            });
            it("mock service relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.mockServiceRelativePath))).to.be.true;
            });
            it("mock service full path", function () {
                expect(fs.existsSync(pact.mockServiceAbsolutePath)).to.be.true;
            });
            it("stub relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.stubRelativePath))).to.be.true;
            });
            it("stub full path", function () {
                expect(fs.existsSync(pact.stubAbsolutePath)).to.be.true;
            });
            it("provider verifier relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.verifierRelativePath))).to.be.true;
            });
            it("provider verifier full path", function () {
                expect(fs.existsSync(pact.verifierAbsolutePath)).to.be.true;
            });
        });
        describe("Linux ia32", function () {
            before(function () { return install_1.default("linux", "ia32"); });
            beforeEach(function () { return pact = pact_standalone_1.standalone("linux", "ia32"); });
            it("broker relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.brokerRelativePath))).to.be.true;
            });
            it("broker full path", function () {
                expect(fs.existsSync(pact.brokerAbsolutePath)).to.be.true;
            });
            it("mock service relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.mockServiceRelativePath))).to.be.true;
            });
            it("mock service full path", function () {
                expect(fs.existsSync(pact.mockServiceAbsolutePath)).to.be.true;
            });
            it("stub relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.stubRelativePath))).to.be.true;
            });
            it("stub full path", function () {
                expect(fs.existsSync(pact.stubAbsolutePath)).to.be.true;
            });
            it("provider verifier relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.verifierRelativePath))).to.be.true;
            });
            it("provider verifier full path", function () {
                expect(fs.existsSync(pact.verifierAbsolutePath)).to.be.true;
            });
        });
        describe("Linux X64", function () {
            before(function () { return install_1.default("linux", "x64"); });
            beforeEach(function () { return pact = pact_standalone_1.standalone("linux", "x64"); });
            it("broker relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.brokerRelativePath))).to.be.true;
            });
            it("broker full path", function () {
                expect(fs.existsSync(pact.brokerAbsolutePath)).to.be.true;
            });
            it("mock service relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.mockServiceRelativePath))).to.be.true;
            });
            it("mock service full path", function () {
                expect(fs.existsSync(pact.mockServiceAbsolutePath)).to.be.true;
            });
            it("stub relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.stubRelativePath))).to.be.true;
            });
            it("stub full path", function () {
                expect(fs.existsSync(pact.stubAbsolutePath)).to.be.true;
            });
            it("provider verifier relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.verifierRelativePath))).to.be.true;
            });
            it("provider verifier full path", function () {
                expect(fs.existsSync(pact.verifierAbsolutePath)).to.be.true;
            });
        });
        describe("Windows", function () {
            before(function () { return install_1.default("win32"); });
            beforeEach(function () { return pact = pact_standalone_1.standalone("win32"); });
            it("should add '.bat' to the end of the binary names", function () {
                expect(pact.brokerRelativePath).to.contain("pact-broker.bat");
                expect(pact.brokerAbsolutePath).to.contain("pact-broker.bat");
                expect(pact.mockServiceRelativePath).to.contain("pact-mock-service.bat");
                expect(pact.mockServiceAbsolutePath).to.contain("pact-mock-service.bat");
                expect(pact.stubRelativePath).to.contain("pact-stub-service.bat");
                expect(pact.stubAbsolutePath).to.contain("pact-stub-service.bat");
                expect(pact.verifierRelativePath).to.contain("pact-provider-verifier.bat");
                expect(pact.verifierAbsolutePath).to.contain("pact-provider-verifier.bat");
            });
            it("broker relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.brokerRelativePath))).to.be.true;
            });
            it("broker full path", function () {
                expect(fs.existsSync(pact.brokerAbsolutePath)).to.be.true;
            });
            it("mock service relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.mockServiceRelativePath))).to.be.true;
            });
            it("mock service full path", function () {
                expect(fs.existsSync(pact.mockServiceAbsolutePath)).to.be.true;
            });
            it("stub relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.stubRelativePath))).to.be.true;
            });
            it("stub full path", function () {
                expect(fs.existsSync(pact.stubAbsolutePath)).to.be.true;
            });
            it("provider verifier relative path", function () {
                expect(fs.existsSync(path.resolve(basePath, pact.verifierRelativePath))).to.be.true;
            });
            it("provider verifier full path", function () {
                expect(fs.existsSync(pact.verifierAbsolutePath)).to.be.true;
            });
        });
    });
});
//# sourceMappingURL=pact-standalone.spec.js.map